function [L,R,U,S,V] = reconstruct_iterSVD(L,R,num_sing, num_iter)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% input:
% L : Squared symmetric matrix containing the left neighborhood information, can be computed as L = M*M'.
%     Because node degrees are unknown, the main diagonal of L is set to 0.
% R : Squared symmetric matrix containing the right neighborhood information, can be computed as R = M'*M;
%     Because node degrees are unknown, the main diagonal of R is set to 0.
% num_sing : Maximum number of singular values to use in SVD.
%
% output:
% L : The same squared symmetric matrix as in the input, but with integer (non-zero) diagonal entries
% R : The same squared symmetric matrix as in the input, but with integer (non-zero) diagonal entries
% U : Left singular matrix of M
% S : Diagonal matrix containing the (unsigned) singular values of M
% V : Right singular matrix of M
%
% description:
% This algorithm uses an iterative heuristic to to update the main diagonal of L and R
% while at the same time obtaining the SVD decomposition of M (but with unsigned singular values).
%
% Written by Dora Erdos, Boston University, 2013
%
%

[n,~] = size(L);
[m,~] = size(R);

if num_sing == 0
	num_sing = min(n,m)
end

% Diagonal matrix that in every iteration contains the current best guess for the main diagonal in L
DL = zeros(n);
% Diagonal matrix that in every iteration contains the current best guess for the main diagonal in R
DR = zeros(m);


Mhat = zeros(n,m);
Mhat_new = zeros(n,m);

%halt after a given number of iterations
for i=1:num_iter
% Halt after the algorithm converges
% while norm(abs(Mhat-Mhatnew),'fro')<0.001	
	% compute eigenvalue decomposition of L using the current best guess DL
	[U,SU] = eigs(L+DL,num_sing);
	[V,SV] = eigs(R+DR,num_sing);
	S = sqrt((SU+SV)/2);
	Mhatnew = U*S*V';
	% update DL and DR
	DL = Mhatnew*Mhatnew'.*eye(n);
	DR = Mhatnew'*Mhatnew.*eye(m);
	Mhat = Mhatnew;
end

L = L + DL;
R = R + DR;

